# Provider components in `ng`

Name | Description
--- | ---
$anchorScrollProvider | Use `$anchorScrollProvider` to disable automatic scrolling whenever $location.hash() changes.
$animateProvider | Default implementation of $animate that doesn't perform any animations, instead just synchronously performs DOM updates and resolves the returned runner promise.
$compileProvider |
$controllerProvider | The $controller service is used by Angular to create new controllers.
$filterProvider | Filters are just functions which transform input to an output. However filters need to be Dependency Injected. To achieve this a filter definition consists of a factory function which is annotated with dependencies and is responsible for creating a filter function.
$httpProvider | Use `$httpProvider` to change the default behavior of the $http service.
$interpolateProvider | Used for configuring the interpolation markup. Defaults to `{{` and `}}`.
$locationProvider | Use the `$locationProvider` to configure how the application deep linking paths are stored.
$logProvider | Use the `$logProvider` to configure how the application logs messages
$parseProvider | `$parseProvider` can be used for configuring the default behavior of the $parse service.
$qProvider |
$rootScopeProvider | Provider for the $rootScope service.
$sceDelegateProvider | The `$sceDelegateProvider` provider allows developers to configure the $sceDelegate service, used as a delegate for Strict Contextual Escaping (SCE).
$sceProvider | The $sceProvider provider allows developers to configure the $sce service. enable/disable Strict Contextual Escaping (SCE) in a module override the default implementation with a custom delegate
$templateRequestProvider | Used to configure the options passed to the `$http` service when making a template request.